@@ -42,6 +42,23 @@ struct _GtefInfoBarClass
 
 GtefInfoBar *		gtef_info_bar_new				(void);
 
+GtefInfoBar *		gtef_info_bar_new_simple			(GtkMessageType  msg_type,
+									 const gchar    *primary_msg,
+									 const gchar    *secondary_msg);
+
+void			gtef_info_bar_add_icon				(GtefInfoBar *info_bar);
+
+void			gtef_info_bar_add_primary_message		(GtefInfoBar *info_bar,
+									 const gchar *primary_msg);
+
+void			gtef_info_bar_add_secondary_message		(GtefInfoBar *info_bar,
+									 const gchar *secondary_msg);
+
+void			gtef_info_bar_add_content_widget		(GtefInfoBar *info_bar,
+									 GtkWidget   *content);
+
+void			gtef_info_bar_add_close_button			(GtefInfoBar *info_bar);
+
 GtkLabel *		gtef_info_bar_create_label			(void);
 
 G_END_DECLS
