@@ -6,7 +6,7 @@
  * Copyright 2000, 2002 - Chema Celorio, Paolo Maggi
  * Copyright 2003-2005 - Paolo Maggi
  *
- * Copyright 2016 - Sébastien Wilmet <swilmet@gnome.org>
+ * Copyright 2016, 2017 - Sébastien Wilmet <swilmet@gnome.org>
  *
  * Gtef is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the
@@ -22,10 +22,8 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "config.h"
 #include "gtef-utils.h"
 #include <string.h>
-#include <glib/gi18n-lib.h>
 
 /**
  * SECTION:utils
@@ -322,97 +320,77 @@ _gtef_utils_strv_copy (const gchar * const *strv)
 	return new_strv;
 }
 
+static gint
+get_menu_item_position (GtkMenuShell *menu_shell,
+			GtkMenuItem  *item)
+{
+	GList *children;
+	GList *l;
+	gint pos;
+	gboolean found = FALSE;
+
+	children = gtk_container_get_children (GTK_CONTAINER (menu_shell));
+
+	for (l = children, pos = 0; l != NULL; l = l->next, pos++)
+	{
+		GtkMenuItem *cur_item = l->data;
+
+		if (cur_item == item)
+		{
+			found = TRUE;
+			break;
+		}
+	}
+
+	g_list_free (children);
+
+	return found ? pos : -1;
+}
+
 /**
- * gtef_utils_menu_item_set_icon_name:
+ * gtef_utils_recent_chooser_menu_get_item_uri:
+ * @menu: a #GtkRecentChooserMenu.
  * @item: a #GtkMenuItem.
- * @icon_name: an icon name.
  *
- * Sets an icon to a #GtkMenuItem.
+ * Gets the URI of @item. @item must be a child of @menu. @menu must be a
+ * #GtkRecentChooserMenu.
  *
+ * This function has been written because the value returned by
+ * gtk_recent_chooser_get_current_uri() is not updated when #GtkMenuItem's of a
+ * #GtkRecentChooserMenu are selected/deselected.
+ *
+ * Returns: the URI of @item. Free with g_free() when no longer needed.
  * Since: 2.0
  */
-/* Based on gtk_model_menu_item_set_icon() from gtkmodelmenuitem.c (private
- * GTK+ class).
- * Copyright 2011, 2013 Canonical Limited
- */
-void
-gtef_utils_menu_item_set_icon_name (GtkMenuItem *item,
-				    const gchar *icon_name)
+gchar *
+gtef_utils_recent_chooser_menu_get_item_uri (GtkRecentChooserMenu *menu,
+					     GtkMenuItem          *item)
 {
-	GtkWidget *child;
+	gint pos;
+	gchar **all_uris;
+	gsize length;
+	gchar *item_uri = NULL;
 
-	g_return_if_fail (GTK_IS_MENU_ITEM (item));
+	g_return_val_if_fail (GTK_IS_RECENT_CHOOSER_MENU (menu), NULL);
+	g_return_val_if_fail (GTK_IS_MENU_ITEM (item), NULL);
 
-	child = gtk_bin_get_child (GTK_BIN (item));
-
-	/* There are only three possibilities here:
-	 *
-	 *   - no child
-	 *   - accel label child
-	 *   - already a box
-	 *
-	 * Handle the no-child case by having GtkMenuItem create the accel
-	 * label, then we will only have two possible cases.
-	 */
-	if (child == NULL)
 	{
-		gtk_menu_item_get_label (item);
-		child = gtk_bin_get_child (GTK_BIN (item));
-		g_return_if_fail (GTK_IS_LABEL (child));
+		GtkWidget *item_parent;
+
+		item_parent = gtk_widget_get_parent (GTK_WIDGET (item));
+		g_return_val_if_fail (item_parent == GTK_WIDGET (menu), NULL);
 	}
 
-	/* If it is a box, make sure there are no images inside of it already. */
-	if (GTK_IS_BOX (child))
+	pos = get_menu_item_position (GTK_MENU_SHELL (menu), item);
+	g_return_val_if_fail (pos >= 0, NULL);
+
+	all_uris = gtk_recent_chooser_get_uris (GTK_RECENT_CHOOSER (menu), &length);
+
+	if ((gsize)pos < length)
 	{
-		GList *children;
-
-		children = gtk_container_get_children (GTK_CONTAINER (child));
-		while (children != NULL)
-		{
-			if (GTK_IS_IMAGE (children->data))
-			{
-				gtk_widget_destroy (children->data);
-			}
-
-			children = g_list_delete_link (children, children);
-		}
-	}
-	else
-	{
-		GtkWidget *box;
-
-		if (icon_name == NULL)
-		{
-			return;
-		}
-
-		box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
-
-		/* Reparent the child without destroying it */
-		g_object_ref (child);
-		gtk_container_remove (GTK_CONTAINER (item), child);
-		gtk_box_pack_end (GTK_BOX (box), child, TRUE, TRUE, 0);
-		g_object_unref (child);
-
-		gtk_container_add (GTK_CONTAINER (item), box);
-		gtk_widget_show (box);
-
-		/* Now we have a box */
-		child = box;
+		item_uri = g_strdup (all_uris[pos]);
 	}
 
-	g_assert (GTK_IS_BOX (child));
-
-	/* child is now a box containing a label and no image. Add the icon,
-	 * if appropriate.
-	 */
-	if (icon_name != NULL)
-	{
-		GtkWidget *image;
-
-		image = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_MENU);
-		gtk_image_set_pixel_size (GTK_IMAGE (image), 16);
-		gtk_box_pack_start (GTK_BOX (child), image, FALSE, FALSE, 0);
-		gtk_widget_show (image);
-	}
+	g_strfreev (all_uris);
+	return item_uri;
 }
